Introduction
============

.. image:: https://readthedocs.org/projects/adafruit-circuitpython-typing/badge/?version=latest
    :target: https://docs.circuitpython.org/projects/adafruit-circuitpython-typing/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/adafruit/Adafruit_CircuitPython_Bundle/blob/main/badges/adafruit_discord.svg
    :target: https://adafru.it/discord
    :alt: Discord

.. image:: https://github.com/adafruit/Adafruit_CircuitPython_Typing/workflows/Build%20CI/badge.svg
    :target: https://github.com/adafruit/Adafruit_CircuitPython_Typing/actions
    :alt: Build Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

Definitions not in the standard `typing` module that are
needed for type annotation of CircuitPython code.

This library is not needed at runtime for CircuitPython code, and does not need to be in the bundle.


Dependencies
=============



Installing from PyPI
=====================

On supported GNU/Linux systems like the Raspberry Pi, you can install the driver locally `from
PyPI <https://pypi.org/project/adafruit-circuitpython-typing/>`_.
To install for current user:

.. code-block:: shell

    pip3 install adafruit-circuitpython-typing

To install system-wide (this may be required in some cases):

.. code-block:: shell

    sudo pip3 install adafruit-circuitpython-typing

To install in a virtual environment in your current project:

.. code-block:: shell

    mkdir project-name && cd project-name
    python3 -m venv .venv
    source .venv/bin/activate
    pip3 install adafruit-circuitpython-typing


Documentation
=============
API documentation for this library can be found on `Read the Docs <https://docs.circuitpython.org/projects/circuitpython_typing/en/latest/>`_.

For information on building library documentation, please check out
`this guide <https://learn.adafruit.com/creating-and-sharing-a-circuitpython-library/sharing-our-docs-on-readthedocs#sphinx-5-1>`_.

Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/adafruit/Adafruit_CircuitPython_Typing/blob/HEAD/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.
